import { XVIDEOS_BASE_URL } from '@/constants/urls';
import { GalleryData, VideoData } from '@/meta/data';

import axios, { AxiosError } from 'axios';

import * as cheerio from "cheerio";
import { findRelatedVideos, findVideoUrlInsideTagStringByFunctionNameAndExtension } from '../../string';
import { getHeaders } from '../headers';

interface FetchParams {
    baseUrl?: string
    query?: string
}

export const fetchVideoData = async (videoId: string, params?: FetchParams): Promise<[VideoData, GalleryData[]]> => {

    let data: VideoData = {
        lowResUrl: ''
    }

    let related: GalleryData[] = [];

    const reqHeaders = getHeaders()

    const queryUrl = `${(params && params.baseUrl) ?? XVIDEOS_BASE_URL}${videoId}`

    await axios.get(queryUrl, reqHeaders)

        .then(response => {

            const html = response.data;


            const $ = cheerio.load(html);

            const scriptTags = $("script");

            // populate video data object
            scriptTags.map((idx, elem) => {

                const lowResUrl = findVideoUrlInsideTagStringByFunctionNameAndExtension($(elem).toString(), 'setVideoUrlLow', '.mp4')
                const hiResUrl = findVideoUrlInsideTagStringByFunctionNameAndExtension($(elem).toString(), 'setVideoUrlHigh', '.mp4')
                const hlsUrl = findVideoUrlInsideTagStringByFunctionNameAndExtension($(elem).toString(), 'setVideoHLS', '.m3u8')

                if (lowResUrl) {
                    data.lowResUrl = lowResUrl;
                }

                if (hiResUrl) {
                    data.hiResUrl = hiResUrl
                }

                if (hlsUrl) {
                    data.hlsUrl = hlsUrl
                }

            })

            // populate related gallery
            scriptTags.map((idx, elem) => {
                const relatedVideos = findRelatedVideos($(elem).toString())

                if (relatedVideos) {
                    related = relatedVideos
                }
            })

        }).catch((error: AxiosError) => {
            // handle errors
        });

    return [data, related];
}